import 'dart:convert';
import 'dart:developer';

import 'package:copilot/src/models/image_response.dart';
import 'package:http/http.dart' as http;
import 'package:http_parser/http_parser.dart';

/// 101 (One-O-One) Gen AI
class OOOGenAIAPIService {
  // String _baseUrl = 'https://api.101gen.ai/';
  String _baseUrl = "https://woundcare-demo.101gen.ai/api";

  set baseUrl(String url) {
    _baseUrl = url;
  }

  Future<ImageResponse> postImage(
      double objectDistance, double focalLength, int capturePpi,
      String filename, String mediaType, List<int> imageData,
      String description
      ) async {
    var uri = Uri.parse('$_baseUrl/images');
    var request = http.MultipartRequest('POST', uri)
      ..fields['od'] = objectDistance.toString()
      ..fields['fl'] = focalLength.toString()
      ..fields['ppi'] = capturePpi.toString()
      ..files.add(http.MultipartFile.fromBytes('file', imageData,
        filename: filename, contentType: MediaType.parse(mediaType)));

    var response = await request.send();
    if (response.statusCode == 200) {
      var responseData = await response.stream.toBytes();
      var responseString = String.fromCharCodes(responseData);
      var responseJson = json.decode(responseString);
      return ImageResponse.fromJson(responseJson);
    } else {
      log('Failed to upload image. Status code: ${response.statusCode}');
      return ImageResponse(images: [], annotations: [], categories: []);
    }
  }
}
