import 'package:freezed_annotation/freezed_annotation.dart';

part 'annotation.freezed.dart';
part 'annotation.g.dart';

@freezed
class Annotation with _$Annotation {
  const factory Annotation(
      {
        /// Unique identifier for the annotation.
        required int id,
        /// Identifier for the image this annotation is associated with.
        @JsonKey(name: 'image_id')
        required int imageId,
        /// Identifier for the category of this annotation.
        @JsonKey(name: 'category_id')
        required int categoryId,
        /// Segmentation of the objects detected.
        required List<List<num>> segmentation,
        /// Area of the object.
        required num area,
        /// Width (rotated bounding box) of the object
        required num width,
        /// Height (rotated bounding box) of the object
        required num height,
        /// Area of the object (in mm^2).
        required num areaMm2,
        /// Width (rotated bounding box) of the object (in mm)
        required num widthMm,
        /// Height (rotated bounding box) of the object (in mm)
        required num heightMm,
        /// Bounding box of the object.
        @JsonKey(name: 'bbox')
        required List<List<num>> boundingBox,
        @Default(0)
        @JsonKey(name: 'iscrowd')
        int isCrowd
      }) = _Annotation;

  factory Annotation.fromJson(Map<String, dynamic> json) =>
      _$AnnotationFromJson(json);
}
